@@ -38,8 +38,42 @@ A `dyndep` is more powerful and general, but also a bit more complicated to set
 
 import importlib.util
 import os
+import re
 
-__all__ = ("write_depfile", "write_dyndep", "import_python_path", "check_script_args")
+__all__ = (
+    "parse_inputs_fls",
+    "write_depfile",
+    "write_dyndep",
+    "import_python_path",
+    "check_script_args",
+)
+
+
+def parse_inputs_fls(fn_fls):
+    """Get local inputs from an fls file."""
+    # Collect inputs and outputs
+    workdir = os.path.dirname(fn_fls)
+    inputs = set()
+    outputs = set()
+    with open(fn_fls) as f:
+        for line in f:
+            if line.startswith("INPUT "):
+                select = inputs
+                path = line[6:].strip()
+            elif line.startswith("OUTPUT "):
+                select = outputs
+                path = line[7:].strip()
+            else:
+                continue
+            path = os.path.normpath(path)
+            if path.startswith("/"):
+                continue
+            path = os.path.join(workdir, path)
+            select.add(path)
+    # When files are both inputs and outputs, skip them.
+    # These are usually aux and out.
+    inputs -= outputs
+    return sorted(inputs)
 
 
 def filter_local_files(paths):
@@ -95,8 +129,10 @@ def import_python_path(path):
 def check_script_args(script_args):
     for script_arg in script_args:
         if isinstance(script_arg, str):
-            if not re.match(r"^[a-zA-Z_-]*$", script_args):
-                raise ValueError("A string script args must match ^[a-zA-Z_-]*$.")
+            if not re.match(r"^[a-zA-Z0-9_-]*$", script_arg):
+                raise ValueError(
+                    "Script argument must only contain letters, numbers, underscores, and hyphens."
+                )  # E:lin101
         elif not isinstance(script_arg, (int, float)):
             raise TypeError("A script argument must be int, float or str.")
     return "".join(f"_{script_arg}" for script_arg in script_args)
